summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xbin/lo-pack-sources2
-rw-r--r--cli_ure/source/scripts/increment_version.pl2
-rw-r--r--cli_ure/source/ure/uno/util/WeakComponentBase.cs4
-rw-r--r--dbaccess/source/ui/inc/brwctrlr.hxx2
-rw-r--r--dbaccess/source/ui/misc/WColumnSelect.cxx2
-rw-r--r--dbaccess/source/ui/querydesign/querycontroller.cxx2
-rw-r--r--dtrans/source/win32/dnd/source.cxx2
-rw-r--r--filter/source/config/cache/filtercache.hxx2
-rw-r--r--framework/source/services/desktop.cxx8
-rw-r--r--include/basegfx/color/bcolormodifier.hxx2
-rw-r--r--include/basegfx/polygon/b2dpolygon.hxx2
-rw-r--r--include/sfx2/shell.hxx2
-rw-r--r--include/svx/svdmodel.hxx2
-rw-r--r--include/svx/svdoedge.hxx2
-rw-r--r--qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java2
-rw-r--r--sc/qa/unit/ucalc_sort.cxx2
-rw-r--r--sc/source/filter/inc/xeescher.hxx2
-rw-r--r--sc/source/filter/inc/xicontent.hxx2
-rw-r--r--sd/source/ui/inc/smarttag.hxx2
-rw-r--r--svgio/inc/svgio/svgreader/svgtools.hxx2
-rw-r--r--svgio/source/svgreader/svgtools.cxx6
-rw-r--r--svtools/source/contnr/treelistbox.cxx2
-rw-r--r--svx/source/fmcomp/fmgridcl.cxx6
-rw-r--r--svx/source/form/fmobj.cxx2
-rw-r--r--svx/source/sdr/contact/viewobjectcontactofgraphic.cxx2
-rw-r--r--sw/source/core/doc/docdesc.cxx2
-rw-r--r--sw/source/core/text/itrform2.cxx2
-rw-r--r--sw/source/core/undo/untbl.cxx2
-rw-r--r--sw/source/filter/html/htmlplug.cxx2
-rw-r--r--sw/source/uibase/docvw/SidebarWin.cxx2
-rw-r--r--toolkit/source/controls/animatedimages.cxx4
-rw-r--r--vcl/osx/printaccessoryview.mm2
-rw-r--r--vcl/osx/salprn.cxx2
-rw-r--r--winaccessibility/source/UAccCOMIDL/ia2_api_all.idl2
-rw-r--r--xmloff/inc/txtflde.hxx2
35 files changed, 44 insertions, 44 deletions
diff --git a/bin/lo-pack-sources b/bin/lo-pack-sources
index 3571638cc45f..fdaf6da6cb62 100755
--- a/bin/lo-pack-sources
+++ b/bin/lo-pack-sources
@@ -244,7 +244,7 @@ sub check_if_file_exists($$)
if (defined $force) {
print "Warning: $file already exists and will be replaced!\n";
} else {
- die "Error: $file alrady exists.\n".
+ die "Error: $file already exists.\n".
" Use --force if you want to replace it.\n";
}
}
diff --git a/cli_ure/source/scripts/increment_version.pl b/cli_ure/source/scripts/increment_version.pl
index dba21aa6ab39..d8606d63a16f 100644
--- a/cli_ure/source/scripts/increment_version.pl
+++ b/cli_ure/source/scripts/increment_version.pl
@@ -96,7 +96,7 @@ if ( $newTypes == 0)
}
else
{
- print "\nNew UNO types were addes since last release. The version will be increased.\n\n";
+ print "\nNew UNO types were added since last release. The version will be increased.\n\n";
}
#read in incVersions in a list
diff --git a/cli_ure/source/ure/uno/util/WeakComponentBase.cs b/cli_ure/source/ure/uno/util/WeakComponentBase.cs
index a20de82da17f..48715afc6ae0 100644
--- a/cli_ure/source/ure/uno/util/WeakComponentBase.cs
+++ b/cli_ure/source/ure/uno/util/WeakComponentBase.cs
@@ -37,8 +37,8 @@ public class WeakComponentBase : WeakBase, XComponent
private bool m_inDispose = false;
private bool m_disposed = false;
- /** Indicates whether object is alrady disposed.
-
+ /** Indicates whether object is already disposed.
+
@return
true, if object has been disposed
*/
diff --git a/dbaccess/source/ui/inc/brwctrlr.hxx b/dbaccess/source/ui/inc/brwctrlr.hxx
index 1f30a833c0f6..013c4e587abd 100644
--- a/dbaccess/source/ui/inc/brwctrlr.hxx
+++ b/dbaccess/source/ui/inc/brwctrlr.hxx
@@ -246,7 +246,7 @@ namespace dbaui
::com::sun::star::uno::Reference< ::com::sun::star::form::XFormComponent > CreateGridModel();
// our default implementation simply instantiates a stardiv.one.form.component.Grid service
- // you most probably don't want to override this behaviuor
+ // you most probably don't want to override this behavior
// the default implementation of disposing distributes the events to the following disposingXXX functions
void disposingGridControl(const ::com::sun::star::lang::EventObject& Source); // calls removeControlListeners
diff --git a/dbaccess/source/ui/misc/WColumnSelect.cxx b/dbaccess/source/ui/misc/WColumnSelect.cxx
index bfe001ab59c3..aa4f7bc74a03 100644
--- a/dbaccess/source/ui/misc/WColumnSelect.cxx
+++ b/dbaccess/source/ui/misc/WColumnSelect.cxx
@@ -366,7 +366,7 @@ void OWizColumnSelect::moveColumn( ListBox* _pRight,
}
// Simply returning fields back to their original position is
-// not enough. We need to take into acccount what fields have
+// not enough. We need to take into account what fields have
// been removed earlier and adjust accordingly. Based on the
// algorithm employed in moveColumn().
sal_uInt16 OWizColumnSelect::adjustColumnPosition( ListBox* _pLeft,
diff --git a/dbaccess/source/ui/querydesign/querycontroller.cxx b/dbaccess/source/ui/querydesign/querycontroller.cxx
index 3c727eb221d6..35349f5803c7 100644
--- a/dbaccess/source/ui/querydesign/querycontroller.cxx
+++ b/dbaccess/source/ui/querydesign/querycontroller.cxx
@@ -890,7 +890,7 @@ void OQueryController::impl_initialize()
rArguments.get_ensureType( OUString(PROPERTY_COMMAND_TYPE), m_nCommandType );
// translate Command/Type into proper members
- // TODO/Later: all this (including those members) should be hidden behind some abstact interface,
+ // TODO/Later: all this (including those members) should be hidden behind some abstract interface,
// which is implemented for all the three commands
switch ( m_nCommandType )
{
diff --git a/dtrans/source/win32/dnd/source.cxx b/dtrans/source/win32/dnd/source.cxx
index b7a1aa0551ed..ffac848ead53 100644
--- a/dtrans/source/win32/dnd/source.cxx
+++ b/dtrans/source/win32/dnd/source.cxx
@@ -124,7 +124,7 @@ void DragSource::StartDragImpl(
// the thread procedure is responsible for the release
acquire();
- // The thread acccesses members of this instance but does not call acquire.
+ // The thread accesses members of this instance but does not call acquire.
// Hopefully this instance is not destroyed before the thread has terminated.
unsigned threadId;
HANDLE hThread= reinterpret_cast<HANDLE>(_beginthreadex(
diff --git a/filter/source/config/cache/filtercache.hxx b/filter/source/config/cache/filtercache.hxx
index f932275e1c6b..1adb87fa328c 100644
--- a/filter/source/config/cache/filtercache.hxx
+++ b/filter/source/config/cache/filtercache.hxx
@@ -241,7 +241,7 @@ class FilterCache : public BaseLock
/// type property names for filter config keyed by EReadOption
css::uno::Sequence< OUString > m_aTypeProps[4];
- /// readonly acccess to the module configuration of OOo
+ /// readonly access to the module configuration of OOo
css::uno::Reference< css::container::XNameAccess > m_xModuleCfg;
rtl::Reference< CacheUpdateListener > m_xTypesChglisteners;
diff --git a/framework/source/services/desktop.cxx b/framework/source/services/desktop.cxx
index 24b9761f5648..ae1e07a5619c 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -810,15 +810,15 @@ sal_Bool SAL_CALL Desktop::isTop() throw( css::uno::RuntimeException, std::excep
void SAL_CALL Desktop::activate() throw( css::uno::RuntimeException, std::exception )
{
- // Desktop is activae always ... but sometimes our frames try to activate
- // the complete path from bottom to top ... And our desktop is the topest frame :-(
+ // Desktop is active always... but sometimes our frames try to activate
+ // the complete path from bottom to top... And our desktop is the topest frame :-(
// So - please don't show any assertions here. Do nothing!
}
void SAL_CALL Desktop::deactivate() throw( css::uno::RuntimeException, std::exception )
{
- // Desktop is activae always ... but sometimes our frames try to deactivate
- // the complete path from bottom to top ... And our desktop is the topest frame :-(
+ // Desktop is active always... but sometimes our frames try to deactivate
+ // the complete path from bottom to top... And our desktop is the topest frame :-(
// So - please don't show any assertions here. Do nothing!
}
diff --git a/include/basegfx/color/bcolormodifier.hxx b/include/basegfx/color/bcolormodifier.hxx
index b6278e045e9d..0acaea3a2d3a 100644
--- a/include/basegfx/color/bcolormodifier.hxx
+++ b/include/basegfx/color/bcolormodifier.hxx
@@ -326,7 +326,7 @@ namespace basegfx
Input are percent values from [-1.0 .. 1-0] which correspond to -100% to 100%
correction of Red, Green, Blue, Luminance or Contrast. 0.0 means no change of
the corresponding channel. All these are combined (but can be used single) to
- - be able to cover a bigger change range utilizing the cmobination
+ - be able to cover a bigger change range utilizing the combination
- allow execution by a small, common, precalculated table
*/
class BASEGFX_DLLPUBLIC SAL_WARN_UNUSED BColorModifier_RGBLuminanceContrast : public BColorModifier
diff --git a/include/basegfx/polygon/b2dpolygon.hxx b/include/basegfx/polygon/b2dpolygon.hxx
index 1ca11b240316..6ef76933eebe 100644
--- a/include/basegfx/polygon/b2dpolygon.hxx
+++ b/include/basegfx/polygon/b2dpolygon.hxx
@@ -118,7 +118,7 @@ namespace basegfx
/** Default adaptive subdivision access
- This method will return a default adapive subdivision of the polygon.
+ This method will return a default adaptive subdivision of the polygon.
If the polygon does not contain any bezier curve segments, it will
just return itself.
diff --git a/include/sfx2/shell.hxx b/include/sfx2/shell.hxx
index 2f16e6aa8a3d..43c79d29088c 100644
--- a/include/sfx2/shell.hxx
+++ b/include/sfx2/shell.hxx
@@ -171,7 +171,7 @@ public:
/**
The connection to a possible corresponding SbxObject is dissolved.
- The SbxObject may continoue to exist, but can not any longer perform
+ The SbxObject may continue to exist, but can not any longer perform
any functions and can not provide any properties.
*/
virtual ~SfxShell();
diff --git a/include/svx/svdmodel.hxx b/include/svx/svdmodel.hxx
index 4d56a4413801..918f6abdad8c 100644
--- a/include/svx/svdmodel.hxx
+++ b/include/svx/svdmodel.hxx
@@ -491,7 +491,7 @@ public:
bool IsSaveOLEPreview() const { return bSaveOLEPreview; }
void SetSaveOLEPreview( bool bSet) { bSaveOLEPreview = bSet; }
- // To accelarate the screen output of Bitmaps (especially rotated ones)
+ // To accelerate the screen output of Bitmaps (especially rotated ones)
// they will be cached. The existence of that cache can be toggled with this
// flag. During the next Paint an image will be remembered or freed.
// If a Bitmap object is placed in Undo its Cache for this object is turned off
diff --git a/include/svx/svdoedge.hxx b/include/svx/svdoedge.hxx
index 756b34225dfb..61b14ffec900 100644
--- a/include/svx/svdoedge.hxx
+++ b/include/svx/svdoedge.hxx
@@ -177,7 +177,7 @@ protected:
// #110649#
// Flag value for avoiding death loops when calculating BoundRects
- // from circularly connected connectors. A coloring algorithm is used
+ // from circulary connected connectors. A coloring algorithm is used
// here. When the GetCurrentBoundRect() calculation of a SdrEdgeObj
// is running, the flag is set, else it is always sal_False.
bool mbBoundRectCalculationRunning : 1;
diff --git a/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java b/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java
index c6bcbd886071..bc079652fba3 100644
--- a/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java
+++ b/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java
@@ -426,7 +426,7 @@ public class _XEventAttacherManager extends MultiMethodTest {
/**
* Test creates object that supports interface <code>XScriptListener</code>,
- * stores it and addes this scripts listener. <p>
+ * stores it and adds this scripts listener. <p>
* Has <b> OK </b> status if the method successfully returns
* and no exceptions were thrown. <p>
* @see com.sun.star.script.XScriptListener
diff --git a/sc/qa/unit/ucalc_sort.cxx b/sc/qa/unit/ucalc_sort.cxx
index 76909f99330c..8e183fff2f20 100644
--- a/sc/qa/unit/ucalc_sort.cxx
+++ b/sc/qa/unit/ucalc_sort.cxx
@@ -477,7 +477,7 @@ void Test::testSortInFormulaGroup()
{ 0, 2, "20" }, { 1, 2, "=A3" },
{ 0, 3, "10" }, { 1, 3, "=A4+1" }, // swap across groups
{ 0, 4, "2" }, { 1, 4, "=A5+1" },
- { 0, 5, "101" }, { 1, 5, "=A6" }, // swap inside contiguious group
+ { 0, 5, "101" }, { 1, 5, "=A6" }, // swap inside contiguous group
{ 0, 6, "100" }, { 1, 6, "=A7" },
{ 0, 7, "102" }, { 1, 7, "=A8" },
{ 0, 8, "104" }, { 1, 8, "=A9" },
diff --git a/sc/source/filter/inc/xeescher.hxx b/sc/source/filter/inc/xeescher.hxx
index 98e08d58c2d9..0feaa3bb4048 100644
--- a/sc/source/filter/inc/xeescher.hxx
+++ b/sc/source/filter/inc/xeescher.hxx
@@ -159,7 +159,7 @@ private:
sal_uInt16 mnRecId; /// Record identifier for the IMGDATA record.
};
-/** Helper class for form controils to manage spreadsheet links . */
+/** Helper class for form controls to manage spreadsheet links . */
class XclExpControlHelper : protected XclExpRoot
{
public:
diff --git a/sc/source/filter/inc/xicontent.hxx b/sc/source/filter/inc/xicontent.hxx
index 181a199745eb..1a76f200503e 100644
--- a/sc/source/filter/inc/xicontent.hxx
+++ b/sc/source/filter/inc/xicontent.hxx
@@ -255,7 +255,7 @@ private:
class XclImpDecryptHelper : private boost::noncopyable
{
public:
- /** Reads the FILEPASS record, queries a password and sets decryption algorihm.
+ /** Reads the FILEPASS record, queries a password and sets decryption algorithm.
@return Error code that may cause an error message after import. */
static ErrCode ReadFilepass( XclImpStream& rStrm );
diff --git a/sd/source/ui/inc/smarttag.hxx b/sd/source/ui/inc/smarttag.hxx
index 9aafedffc6ca..291c600a1cdb 100644
--- a/sd/source/ui/inc/smarttag.hxx
+++ b/sd/source/ui/inc/smarttag.hxx
@@ -123,7 +123,7 @@ public:
/** disposes all smart tags and clears the set */
void Dispose();
- /** addes the handles from all smart tags to the given list */
+ /** adds the handles from all smart tags to the given list */
void addCustomHandles( SdrHdlList& rHandlerList );
/** returns true if the currently selected smart tag has
diff --git a/svgio/inc/svgio/svgreader/svgtools.hxx b/svgio/inc/svgio/svgreader/svgtools.hxx
index d6781c99963e..5fc6c3b5a4f7 100644
--- a/svgio/inc/svgio/svgreader/svgtools.hxx
+++ b/svgio/inc/svgio/svgreader/svgtools.hxx
@@ -220,7 +220,7 @@ namespace svgio
void readImageLink(const OUString& rCandidate, OUString& rXLink, OUString& rUrl, OUString& rMimeType, OUString& rData);
OUString convert(const OUString& rCandidate, const sal_Unicode& rPattern, const sal_Unicode& rNew, bool bRemove);
- OUString consolidateContiguosSpace(const OUString& rCandidate);
+ OUString consolidateContiguousSpace(const OUString& rCandidate);
OUString whiteSpaceHandlingDefault(const OUString& rCandidate);
OUString whiteSpaceHandlingPreserve(const OUString& rCandidate);
diff --git a/svtools/source/contnr/treelistbox.cxx b/svtools/source/contnr/treelistbox.cxx
index 2730afeae235..a1f21fa35010 100644
--- a/svtools/source/contnr/treelistbox.cxx
+++ b/svtools/source/contnr/treelistbox.cxx
@@ -3870,7 +3870,7 @@ void SvTreeListBox::EnableList( bool _bEnable )
::com::sun::star::uno::Reference< XAccessible > xAccParent = pParent->GetAccessible();
if ( xAccParent.is() )
{
- // need to be done here to get the vclxwindow later on in the accessbile
+ // need to be done here to get the vclxwindow later on in the accessible
::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer > xTemp(GetComponentInterface());
xAccessible = pImp->m_aFactoryAccess.getFactory().createAccessibleTreeListBox( *this, xAccParent );
}
diff --git a/svx/source/fmcomp/fmgridcl.cxx b/svx/source/fmcomp/fmgridcl.cxx
index b01c1f5d3c81..c5a9c446186e 100644
--- a/svx/source/fmcomp/fmgridcl.cxx
+++ b/svx/source/fmcomp/fmgridcl.cxx
@@ -1809,11 +1809,11 @@ Sequence< Any> FmGridControl::getSelectionBookmarks()
// navigation bar and the grid. The latter itself will result in SeekRow calls. So after (successfully) returning
// from the moveRelative the getPosition returns an invalid value. And so the SeekCursor fails.
// In the consequence ALL parts of code where two calls to the seek cursor are done, while the second call _relys_ on
- // the first one, should be secured against recursion, with a broad-minded interpretion of "recursion" : if any of these
- // code parts is executed, no other should be accessible. But this sounds very difficult to achieve ....
+ // the first one, should be secured against recursion, with a broad-minded interpretion of "recursion": if any of these
+ // code parts is executed, no other should be accessible. But this sounds very difficult to achieve...
// )
- // The next problem caused by the same behaviuor (SeekCursor causes a propertyChanged) : when adjusting rows we implicitly
+ // The next problem caused by the same behavior (SeekCursor causes a propertyChanged): when adjusting rows we implicitly
// change our selection. So a "FirstSelected(); SeekCursor(); NextSelected();" may produce unpredictable results.
// That's why we _first_ collect the indices of the selected rows and _then_ their bookmarks.
long nIdx = FirstSelectedRow();
diff --git a/svx/source/form/fmobj.cxx b/svx/source/form/fmobj.cxx
index 0ce45b66c130..280da5f0a2f5 100644
--- a/svx/source/form/fmobj.cxx
+++ b/svx/source/form/fmobj.cxx
@@ -560,7 +560,7 @@ Reference< XInterface > FmFormObj::ensureModelEnv(const Reference< XInterface >
xDestContainer->insertByIndex(nCurrentDestIndex, makeAny(xCurrentDestForm));
++nCurrentDestIndex;
- // like nCurrentSourceIndex, nCurrentDestIndex now points 'behind' the form it actally means
+ // like nCurrentSourceIndex, nCurrentDestIndex now points 'behind' the form it actually means
}
catch(Exception&)
{
diff --git a/svx/source/sdr/contact/viewobjectcontactofgraphic.cxx b/svx/source/sdr/contact/viewobjectcontactofgraphic.cxx
index 4a8f469c4574..53fc85de13db 100644
--- a/svx/source/sdr/contact/viewobjectcontactofgraphic.cxx
+++ b/svx/source/sdr/contact/viewobjectcontactofgraphic.cxx
@@ -212,7 +212,7 @@ namespace sdr
// #i103720# forget event to avoid possible deletion by the following ActionChanged call
// which may use createPrimitive2DSequence/impPrepareGraphicWithAsynchroniousLoading again.
- // Deletion is actally done by the scheduler who leaded to coming here
+ // Deletion is actually done by the scheduler who leaded to coming here
mpAsynchLoadEvent = 0;
// Invalidate all paint areas and check existing animation (which may have changed).
diff --git a/sw/source/core/doc/docdesc.cxx b/sw/source/core/doc/docdesc.cxx
index 1583090703d0..240d2ea3d518 100644
--- a/sw/source/core/doc/docdesc.cxx
+++ b/sw/source/core/doc/docdesc.cxx
@@ -249,7 +249,7 @@ void SwDoc::CopyMasterHeader(const SwPageDesc &rChged, const SwFormatHeader &rHe
rDescFrameFormat.SetFormatAttr( rDesc.GetMaster().GetHeader() );
}
else if ( rHead.IsActive() )
- { // Left or first gets its own header if the Format doesn't alrady have one.
+ { // Left or first gets its own header if the Format doesn't already have one.
// If it already has one and it points to the same Section as the
// Right one, it needs to get an own Header.
// The content is evidently copied.
diff --git a/sw/source/core/text/itrform2.cxx b/sw/source/core/text/itrform2.cxx
index 5ecb0b3f4bae..bc359f974994 100644
--- a/sw/source/core/text/itrform2.cxx
+++ b/sw/source/core/text/itrform2.cxx
@@ -1753,7 +1753,7 @@ void SwTextFormatter::CalcRealHeight( bool bNewLine )
// Word will render < 50% too but it's just not readable
if( nTmp < 50 )
nTmp = nTmp ? 50 : 100;
- if (nTmp<100) { // code adaped from fixed line height
+ if (nTmp<100) { // code adapted from fixed line height
nTmp *= nLineHeight;
nTmp /= 100;
if( !nTmp )
diff --git a/sw/source/core/undo/untbl.cxx b/sw/source/core/undo/untbl.cxx
index 83bbe44e9fcb..c2c34a086ced 100644
--- a/sw/source/core/undo/untbl.cxx
+++ b/sw/source/core/undo/untbl.cxx
@@ -193,7 +193,7 @@ void CheckTable( const SwTable& );
/* #130880: Crash in undo of table to text when the table has (freshly) merged cells
The order of cell content nodes in the nodes array is not given by the recursive table structure.
-The algorithmn must not rely on this even it holds for a fresh loaded table in odt file format.
+The algorithm must not rely on this even it holds for a fresh loaded table in odt file format.
So we need to remember not only the start node position but the end node position as well.
*/
diff --git a/sw/source/filter/html/htmlplug.cxx b/sw/source/filter/html/htmlplug.cxx
index b9e14257454a..8271967e7810 100644
--- a/sw/source/filter/html/htmlplug.cxx
+++ b/sw/source/filter/html/htmlplug.cxx
@@ -130,7 +130,7 @@ void SwHTMLParser::SetFixSize( const Size& rPixSize,
SvxCSS1PropertyInfo& rCSS1PropInfo,
SfxItemSet& rFlyItemSet )
{
- // absolulte Groessenangaben in Twip umrechnen
+ // absolute Groessenangaben in Twip umrechnen
sal_uInt8 nPrcWidth = 0, nPrcHeight = 0;
Size aTwipSz( bPrcWidth || USHRT_MAX==rPixSize.Width() ? 0 : rPixSize.Width(),
bPrcHeight || USHRT_MAX==rPixSize.Height() ? 0 : rPixSize.Height() );
diff --git a/sw/source/uibase/docvw/SidebarWin.cxx b/sw/source/uibase/docvw/SidebarWin.cxx
index 28da61c427bf..8bf1c98a1dc7 100644
--- a/sw/source/uibase/docvw/SidebarWin.cxx
+++ b/sw/source/uibase/docvw/SidebarWin.cxx
@@ -896,7 +896,7 @@ void SwSidebarWin::SetColor(Color aColorDark,Color aColorLight, Color aColorAnch
AllSettings aSettings2 = mpVScrollbar->GetSettings();
StyleSettings aStyleSettings2 = aSettings2.GetStyleSettings();
aStyleSettings2.SetButtonTextColor(Color(0,0,0));
- aStyleSettings2.SetCheckedColor(mColorLight); // backgound
+ aStyleSettings2.SetCheckedColor(mColorLight); // background
aStyleSettings2.SetShadowColor(mColorAnchor);
aStyleSettings2.SetFaceColor(mColorDark);
aSettings2.SetStyleSettings(aStyleSettings2);
diff --git a/toolkit/source/controls/animatedimages.cxx b/toolkit/source/controls/animatedimages.cxx
index 97fd0166a32c..a434239b9ad4 100644
--- a/toolkit/source/controls/animatedimages.cxx
+++ b/toolkit/source/controls/animatedimages.cxx
@@ -435,7 +435,7 @@ namespace toolkit {
lcl_checkIndex( *m_xData, i_index, *this, true );
- // actaul insertion
+ // actual insertion
m_xData->aImageSets.insert( m_xData->aImageSets.begin() + i_index, i_imageURLs );
// listener notification
@@ -452,7 +452,7 @@ namespace toolkit {
lcl_checkIndex( *m_xData, i_index, *this );
- // actaul insertion
+ // actual insertion
m_xData->aImageSets[ i_index ] = i_imageURLs;
// listener notification
diff --git a/vcl/osx/printaccessoryview.mm b/vcl/osx/printaccessoryview.mm
index d936c4ac576d..3958bb1c63d9 100644
--- a/vcl/osx/printaccessoryview.mm
+++ b/vcl/osx/printaccessoryview.mm
@@ -45,7 +45,7 @@ using namespace com::sun::star;
using namespace com::sun::star::beans;
using namespace com::sun::star::uno;
-/* Note: the accesory view as implemented here is already deprecated in Leopard. Unfortunately
+/* Note: the accessory view as implemented here is already deprecated in Leopard. Unfortunately
as long as our baseline is Tiger we cannot gain the advantages over multiple accessory views
as well havs having accessory views AND a preview (as long as you are linked vs. 10.4 libraries
the preview insists on not being present. This is unfortunate.
diff --git a/vcl/osx/salprn.cxx b/vcl/osx/salprn.cxx
index ddb8cc7850d9..99684315c488 100644
--- a/vcl/osx/salprn.cxx
+++ b/vcl/osx/salprn.cxx
@@ -493,7 +493,7 @@ bool AquaSalInfoPrinter::StartJob( const OUString* i_pFileName,
if( [pPrintOperation respondsToSelector: @selector(setJobTitle:)] )
[pPrintOperation performSelector: @selector(setJobTitle:) withObject: [CreateNSString( i_rJobName ) autorelease]];
- if( bShowPanel && mnCurPageRangeStart == 0 && nCurJob == 0) // only the first range of pages (in the first job) gets the accesory view
+ if( bShowPanel && mnCurPageRangeStart == 0 && nCurJob == 0) // only the first range of pages (in the first job) gets the accessory view
pReleaseAfterUse = [AquaPrintAccessoryView setupPrinterPanel: pPrintOperation withController: &i_rController withState: &aAccViewState];
bSuccess = true;
diff --git a/winaccessibility/source/UAccCOMIDL/ia2_api_all.idl b/winaccessibility/source/UAccCOMIDL/ia2_api_all.idl
index 36f67e41a68c..34b61c2a6a6d 100644
--- a/winaccessibility/source/UAccCOMIDL/ia2_api_all.idl
+++ b/winaccessibility/source/UAccCOMIDL/ia2_api_all.idl
@@ -4822,7 +4822,7 @@ interface IAccessibleTableCell : IUnknown
[out, retval] boolean *isSelected
);
- /** @brief Returns a reference to the accessbile of the containing table.
+ /** @brief Returns a reference to the accessible of the containing table.
@param [out] table
Returns a reference to the IUnknown of the containing table.
diff --git a/xmloff/inc/txtflde.hxx b/xmloff/inc/txtflde.hxx
index 9cb74a7d963b..7bbaa791470c 100644
--- a/xmloff/inc/txtflde.hxx
+++ b/xmloff/inc/txtflde.hxx
@@ -59,7 +59,7 @@ enum FieldIdEnum {
FIELD_ID_TIME, // current time (+date)
FIELD_ID_PAGENAME, // page/slide name
FIELD_ID_PAGENUMBER, // page number
- FIELD_ID_PAGESTRING, // page contination string (page number string)
+ FIELD_ID_PAGESTRING, // page continuation string (page number string)
FIELD_ID_REFPAGE_SET, // set reference page
FIELD_ID_REFPAGE_GET, // get reference page number
diff --git a/svgio/source/svgreader/svgtools.cxx b/svgio/source/svgreader/svgtools.cxx
index 5ae5830c2996..5cd34792b6a4 100644
--- a/svgio/source/svgreader/svgtools.cxx
+++ b/svgio/source/svgreader/svgtools.cxx
@@ -1567,7 +1567,7 @@ namespace svgio
return rCandidate;
}
- OUString consolidateContiguosSpace(const OUString& rCandidate)
+ OUString consolidateContiguousSpace(const OUString& rCandidate)
{
const sal_Int32 nLen(rCandidate.getLength());
@@ -1629,8 +1629,8 @@ namespace svgio
// strip of all leading and trailing spaces
aRetval = aRetval.trim();
- // consolidate contiguos space
- aRetval = consolidateContiguosSpace(aRetval);
+ // consolidate contiguous space
+ aRetval = consolidateContiguousSpace(aRetval);
return aRetval;
}